@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2020 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -46,6 +46,8 @@
 
 #include "DASSL-opts.cc"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Global pointer for user defined function required by dassl.
 static octave_value dassl_fcn;
 
@@ -59,13 +61,13 @@ static bool warned_jac_imaginary = false;
 // Is this a recursive call?
 static int call_depth = 0;
 
-ColumnVector
+static ColumnVector
 dassl_user_function (const ColumnVector& x, const ColumnVector& xdot,
                      double t, octave_idx_type& ires)
 {
   ColumnVector retval;
 
-  assert (x.numel () == xdot.numel ());
+  error_unless (x.numel () == xdot.numel ());
 
   octave_value_list args;
 
@@ -79,11 +81,11 @@ dassl_user_function (const ColumnVector& x, const ColumnVector& xdot,
 
       try
         {
-          tmp = octave::feval (dassl_fcn, args, 1);
+          tmp = feval (dassl_fcn, args, 1);
         }
-      catch (octave::execution_exception& e)
+      catch (execution_exception& ee)
         {
-          err_user_supplied_eval (e, "dassl");
+          err_user_supplied_eval (ee, "dassl");
         }
 
       int tlen = tmp.length ();
@@ -108,13 +110,13 @@ dassl_user_function (const ColumnVector& x, const ColumnVector& xdot,
   return retval;
 }
 
-Matrix
+static Matrix
 dassl_user_jacobian (const ColumnVector& x, const ColumnVector& xdot,
                      double t, double cj)
 {
   Matrix retval;
 
-  assert (x.numel () == xdot.numel ());
+  error_unless (x.numel () == xdot.numel ());
 
   octave_value_list args;
 
@@ -129,11 +131,11 @@ dassl_user_jacobian (const ColumnVector& x, const ColumnVector& xdot,
 
       try
         {
-          tmp = octave::feval (dassl_jac, args, 1);
+          tmp = feval (dassl_jac, args, 1);
         }
-      catch (octave::execution_exception& e)
+      catch (execution_exception& ee)
         {
-          err_user_supplied_eval (e, "dassl");
+          err_user_supplied_eval (ee, "dassl");
         }
 
       int tlen = tmp.length ();
@@ -269,9 +271,7 @@ parameters for @code{dassl}.
 
   octave_value_list retval (4);
 
-  octave::unwind_protect frame;
-
-  frame.protect_var (call_depth);
+  unwind_protect_var<int> restore_var (call_depth);
   call_depth++;
 
   if (call_depth > 1)
@@ -294,13 +294,11 @@ parameters for @code{dassl}.
         f_arg = c(0);
       else if (c.numel () == 2)
         {
-          dassl_fcn = octave::get_function_handle (interp, c(0),
-                                                   fcn_param_names);
+          dassl_fcn = get_function_handle (interp, c(0), fcn_param_names);
 
           if (dassl_fcn.is_defined ())
             {
-              dassl_jac = octave::get_function_handle (interp, c(1),
-                                                       jac_param_names);
+              dassl_jac = get_function_handle (interp, c(1), jac_param_names);
 
               if (dassl_jac.is_undefined ())
                 dassl_fcn = octave_value ();
@@ -319,21 +317,20 @@ parameters for @code{dassl}.
           switch (f_arg.rows ())
             {
             case 1:
-              dassl_fcn = octave::get_function_handle (interp, f_arg,
-                                                       fcn_param_names);
+              dassl_fcn = get_function_handle (interp, f_arg, fcn_param_names);
               break;
 
             case 2:
               {
                 string_vector tmp = f_arg.string_vector_value ();
 
-                dassl_fcn = octave::get_function_handle (interp, tmp(0),
-                                                         fcn_param_names);
+                dassl_fcn = get_function_handle (interp, tmp(0),
+                                                 fcn_param_names);
 
                 if (dassl_fcn.is_defined ())
                   {
-                    dassl_jac = octave::get_function_handle (interp, tmp(1),
-                                                             jac_param_names);
+                    dassl_jac = get_function_handle (interp, tmp(1),
+                                                     jac_param_names);
 
                     if (dassl_jac.is_undefined ())
                       dassl_fcn = octave_value ();
@@ -370,11 +367,11 @@ parameters for @code{dassl}.
 
   double tzero = out_times (0);
 
-  DAEFunc func (dassl_user_function);
+  DAEFunc fcn (dassl_user_function);
   if (dassl_jac.is_defined ())
-    func.set_jacobian_function (dassl_user_jacobian);
+    fcn.set_jacobian_function (dassl_user_jacobian);
 
-  DASSL dae (state, deriv, tzero, func);
+  DASSL dae (state, deriv, tzero, fcn);
 
   dae.set_options (dassl_opts);
 
@@ -493,3 +490,5 @@ parameters for @code{dassl}.
 
 %!error dassl_options ("foo", 1, 2)
 */
+
+OCTAVE_END_NAMESPACE(octave)
