@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -35,6 +35,8 @@
 #include "ovl.h"
 #include "utils.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 static octave_value
 do_fft (const octave_value_list& args, const char *fcn, int type)
 {
@@ -55,10 +57,10 @@ do_fft (const octave_value_list& args, const char *fcn, int type)
       if (! args(1).isempty ())
         {
           double dval = args(1).double_value ();
-          if (octave::math::isnan (dval))
+          if (math::isnan (dval))
             error ("%s: number of points (N) cannot be NaN", fcn);
 
-          n_points = octave::math::nint_big (dval);
+          n_points = math::nint_big (dval);
           if (n_points < 0)
             error ("%s: number of points (N) must be greater than zero", fcn);
         }
@@ -67,14 +69,14 @@ do_fft (const octave_value_list& args, const char *fcn, int type)
   if (nargin > 2)
     {
       double dval = args(2).double_value ();
-      if (octave::math::isnan (dval))
+      if (math::isnan (dval))
         error ("%s: DIM cannot be NaN", fcn);
       else if (dval < 1 || dval > ndims)
         error ("%s: DIM must be a valid dimension along which to perform FFT",
                fcn);
       else
         // to be safe, cast it back to int since dim is an int
-        dim = octave::math::nint (dval) - 1;
+        dim = math::nint (dval) - 1;
     }
 
   // FIXME: This seems strange and unnecessary (10/21/16).
@@ -111,9 +113,9 @@ do_fft (const octave_value_list& args, const char *fcn, int type)
       octave_value_list idx (ndims);
       for (octave_idx_type i = 0; i < ndims; i++)
         idx(i) = idx_vector::colon;
-      idx(dim) = idx_vector (static_cast<octave_idx_type> (0));
+      idx(dim) = idx_vector (0);
 
-      return arg.do_index_op (idx);
+      return arg.index_op (idx);
     }
 
   if (arg.is_single_type ())
@@ -187,15 +189,15 @@ do_fft (const octave_value_list& args, const char *fcn, int type)
 %!testif HAVE_FFTW
 %! assert (fft (eye (2,2,"single")), single ([1,1; 1,-1]))
 
-%!error (fft ())
+%!error fft ()
 */
 
 
 DEFUN (fft, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} fft (@var{x})
-@deftypefnx {} {} fft (@var{x}, @var{n})
-@deftypefnx {} {} fft (@var{x}, @var{n}, @var{dim})
+@deftypefn  {} {@var{y} =} fft (@var{x})
+@deftypefnx {} {@var{y} =} fft (@var{x}, @var{n})
+@deftypefnx {} {@var{y} =} fft (@var{x}, @var{n}, @var{dim})
 Compute the discrete Fourier transform of @var{x} using
 a Fast Fourier Transform (FFT) algorithm.
 
@@ -222,23 +224,23 @@ dimension of the matrix along which the FFT is performed.
 
 DEFUN (ifft, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} ifft (@var{x})
-@deftypefnx {} {} ifft (@var{x}, @var{n})
-@deftypefnx {} {} ifft (@var{x}, @var{n}, @var{dim})
-Compute the inverse discrete Fourier transform of @var{x}
+@deftypefn  {} {@var{x} =} ifft (@var{y})
+@deftypefnx {} {@var{x} =} ifft (@var{y}, @var{n})
+@deftypefnx {} {@var{x} =} ifft (@var{y}, @var{n}, @var{dim})
+Compute the inverse discrete Fourier transform of @var{y}
 using a Fast Fourier Transform (FFT) algorithm.
 
 The inverse FFT is calculated along the first non-singleton dimension
-of the array.  Thus if @var{x} is a matrix, @code{fft (@var{x})} computes
-the inverse FFT for each column of @var{x}.
+of the array.  Thus if @var{y} is a matrix, @code{ifft (@var{y})} computes
+the inverse FFT for each column of @var{y}.
 
 If called with two arguments, @var{n} is expected to be an integer
-specifying the number of elements of @var{x} to use, or an empty
+specifying the number of elements of @var{y} to use, or an empty
 matrix to specify that its value should be ignored.  If @var{n} is
 larger than the dimension along which the inverse FFT is calculated, then
-@var{x} is resized and padded with zeros.  Otherwise, if @var{n} is
+@var{y} is resized and padded with zeros.  Otherwise, if @var{n} is
 smaller than the dimension along which the inverse FFT is calculated,
-then @var{x} is truncated.
+then @var{y} is truncated.
 
 If called with three arguments, @var{dim} is an integer specifying the
 dimension of the matrix along which the inverse FFT is performed.
@@ -294,7 +296,7 @@ dimension of the matrix along which the inverse FFT is performed.
 %! answer(n+1) = N/2;
 %! answer(N-n+1) = N/2;
 %!
-%! assert (S, answer, 4*N*eps ("single"));
+%! assert (S, answer, 4*N* eps ("single"));
 
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
@@ -309,5 +311,7 @@ dimension of the matrix along which the inverse FFT is performed.
 %! S(n+1) = N/2;
 %! S(N-n+1) = N/2;
 %!
-%! assert (ifft (S), s, 4*N*eps ("single"));
+%! assert (ifft (S), s, 4*N* eps ("single"));
 */
+
+OCTAVE_END_NAMESPACE(octave)
