@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2022 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,7 +33,7 @@
 
 #include "oct-stream.h"
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 class
 base_strstream : public base_stream
@@ -42,7 +42,7 @@ public:
 
   base_strstream (std::ios::openmode m = std::ios::out,
                   mach_info::float_format ff
-                    = mach_info::native_float_format (),
+                  = mach_info::native_float_format (),
                   const std::string& encoding = "utf-8")
     : base_stream (m, ff, encoding) { }
 
@@ -192,7 +192,7 @@ private:
   std::ostringstream m_ostream;
 };
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
 
 #if defined (OCTAVE_PROVIDE_DEPRECATED_SYMBOLS)
 
