@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2021 The Octave Project Developers
+// Copyright (C) 1998-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -43,6 +43,8 @@
 #include "oct-spparms.h"
 #include "sparse-xdiv.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 static void
 solve_singularity_warning (double rcond)
 {
@@ -334,28 +336,28 @@ RT do_rightdiv_sm_dm (const SM& a, const DM& d)
 
 // -*- 9 -*-
 SparseMatrix
-xdiv (const SparseMatrix& a, const DiagMatrix& b, MatrixType &)
+xdiv (const SparseMatrix& a, const DiagMatrix& b, MatrixType&)
 {
   return do_rightdiv_sm_dm<SparseMatrix> (a, b);
 }
 
 // -*- 10 -*-
 SparseComplexMatrix
-xdiv (const SparseMatrix& a, const ComplexDiagMatrix& b, MatrixType &)
+xdiv (const SparseMatrix& a, const ComplexDiagMatrix& b, MatrixType&)
 {
   return do_rightdiv_sm_dm<SparseComplexMatrix> (a, b);
 }
 
 // -*- 11 -*-
 SparseComplexMatrix
-xdiv (const SparseComplexMatrix& a, const DiagMatrix& b, MatrixType &)
+xdiv (const SparseComplexMatrix& a, const DiagMatrix& b, MatrixType&)
 {
   return do_rightdiv_sm_dm<SparseComplexMatrix> (a, b);
 }
 
 // -*- 12 -*-
 SparseComplexMatrix
-xdiv (const SparseComplexMatrix& a, const ComplexDiagMatrix& b, MatrixType &)
+xdiv (const SparseComplexMatrix& a, const ComplexDiagMatrix& b, MatrixType&)
 {
   return do_rightdiv_sm_dm<SparseComplexMatrix> (a, b);
 }
@@ -370,7 +372,7 @@ xdiv (const SparseComplexMatrix& a, const ComplexDiagMatrix& b, MatrixType &)
 //                  +---+----+
 
 Matrix
-x_el_div (double a, const SparseMatrix& b)
+elem_xdiv (double a, const SparseMatrix& b)
 {
   octave_idx_type nr = b.rows ();
   octave_idx_type nc = b.cols ();
@@ -394,7 +396,7 @@ x_el_div (double a, const SparseMatrix& b)
 }
 
 ComplexMatrix
-x_el_div (double a, const SparseComplexMatrix& b)
+elem_xdiv (double a, const SparseComplexMatrix& b)
 {
   octave_idx_type nr = b.rows ();
   octave_idx_type nc = b.cols ();
@@ -413,7 +415,7 @@ x_el_div (double a, const SparseComplexMatrix& b)
 }
 
 ComplexMatrix
-x_el_div (const Complex a, const SparseMatrix& b)
+elem_xdiv (const Complex& a, const SparseMatrix& b)
 {
   octave_idx_type nr = b.rows ();
   octave_idx_type nc = b.cols ();
@@ -431,7 +433,7 @@ x_el_div (const Complex a, const SparseMatrix& b)
 }
 
 ComplexMatrix
-x_el_div (const Complex a, const SparseComplexMatrix& b)
+elem_xdiv (const Complex& a, const SparseComplexMatrix& b)
 {
   octave_idx_type nr = b.rows ();
   octave_idx_type nc = b.cols ();
@@ -633,3 +635,5 @@ xleftdiv (const ComplexDiagMatrix& d, const SparseComplexMatrix& a,
 {
   return do_leftdiv_dm_sm<SparseComplexMatrix> (d, a);
 }
+
+OCTAVE_END_NAMESPACE(octave)
