@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -30,6 +30,7 @@
 #include <sstream>
 
 #include "file-info.h"
+#include "file-ops.h"
 #include "file-stat.h"
 #include "str-vec.h"
 
@@ -45,7 +46,6 @@
 #include "ov.h"
 #include "pager.h"
 #include "pt-eval.h"
-#include "pt-jit.h"
 #include "pt-jump.h"
 #include "pt-misc.h"
 #include "pt-pr-code.h"
@@ -73,32 +73,31 @@ octave_user_code::~octave_user_code (void)
   m_scope.set_user_code (nullptr);
 
   // FIXME: shouldn't this happen automatically when deleting cmd_list?
-  if (cmd_list)
+  if (m_cmd_list)
     {
-      octave::event_manager& evmgr
-        = octave::__get_event_manager__ ("octave_user_code::~octave_user_code");
+      octave::event_manager& evmgr = octave::__get_event_manager__ ();
 
-      cmd_list->remove_all_breakpoints (evmgr, file_name);
+      m_cmd_list->remove_all_breakpoints (evmgr, m_file_name);
     }
 
-  delete cmd_list;
+  delete m_cmd_list;
   delete m_file_info;
 }
 
 void
 octave_user_code::get_file_info (void)
 {
-  m_file_info = new octave::file_info (file_name);
+  m_file_info = new octave::file_info (m_file_name);
 
-  octave::sys::file_stat fs (file_name);
+  octave::sys::file_stat fs (m_file_name);
 
   if (fs && (fs.mtime () > time_parsed ()))
     warning ("function file '%s' changed since it was parsed",
-             file_name.c_str ());
+             m_file_name.c_str ());
 }
 
 std::string
-octave_user_code::get_code_line (size_t line)
+octave_user_code::get_code_line (std::size_t line)
 {
   if (! m_file_info)
     get_file_info ();
@@ -107,7 +106,7 @@ octave_user_code::get_code_line (size_t line)
 }
 
 std::deque<std::string>
-octave_user_code::get_code_lines (size_t line, size_t num_lines)
+octave_user_code::get_code_lines (std::size_t line, std::size_t num_lines)
 {
   if (! m_file_info)
     get_file_info ();
@@ -138,10 +137,11 @@ octave_value
 octave_user_code::dump (void) const
 {
   std::map<std::string, octave_value> m
-    = {{ "scope_info", m_scope ? m_scope.dump () : "0x0" },
-       { "file_name", file_name },
-       { "time_parsed", t_parsed },
-       { "time_checked", t_checked }};
+  = {{ "scope_info", m_scope ? m_scope.dump () : "0x0" },
+    { "m_file_name", m_file_name },
+    { "time_parsed", m_t_parsed },
+    { "time_checked", m_t_checked }
+  };
 
   return octave_value (m);
 }
@@ -158,19 +158,19 @@ octave_user_script::octave_user_script (void)
 { }
 
 octave_user_script::octave_user_script
-  (const std::string& fnm, const std::string& nm,
-   const octave::symbol_scope& scope, octave::tree_statement_list *cmds,
-   const std::string& ds)
+(const std::string& fnm, const std::string& nm,
+ const octave::symbol_scope& scope, octave::tree_statement_list *cmds,
+ const std::string& ds)
   : octave_user_code (fnm, nm, scope, cmds, ds)
 {
-  if (cmd_list)
-    cmd_list->mark_as_script_body ();
+  if (m_cmd_list)
+    m_cmd_list->mark_as_script_body ();
 }
 
 octave_user_script::octave_user_script
-  (const std::string& fnm, const std::string& nm,
-   const octave::symbol_scope& scope, const std::string& ds)
-    : octave_user_code (fnm, nm, scope, nullptr, ds)
+(const std::string& fnm, const std::string& nm,
+ const octave::symbol_scope& scope, const std::string& ds)
+  : octave_user_code (fnm, nm, scope, nullptr, ds)
 { }
 
 // We must overload the call method so that we call the proper
@@ -212,41 +212,34 @@ DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_user_function,
 // extrinsic/intrinsic state?).
 
 octave_user_function::octave_user_function
-  (const octave::symbol_scope& scope, octave::tree_parameter_list *pl,
-   octave::tree_parameter_list *rl, octave::tree_statement_list *cl)
+(const octave::symbol_scope& scope, octave::tree_parameter_list *pl,
+ octave::tree_parameter_list *rl, octave::tree_statement_list *cl)
   : octave_user_code ("", "", scope, cl, ""),
-    param_list (pl), ret_list (rl),
-    lead_comm (), trail_comm (),
-    location_line (0), location_column (0),
-    parent_name (), system_fcn_file (false),
-    num_named_args (param_list ? param_list->length () : 0),
-    subfunction (false), inline_function (false),
-    anonymous_function (false), nested_function (false),
-    class_constructor (none), class_method (none)
-#if defined (HAVE_LLVM)
-    , jit_info (0)
-#endif
+    m_param_list (pl), m_ret_list (rl),
+    m_lead_comm (), m_trail_comm (),
+    m_location_line (0), m_location_column (0),
+    m_system_fcn_file (false),
+    m_num_named_args (m_param_list ? m_param_list->length () : 0),
+    m_subfunction (false), m_inline_function (false),
+    m_anonymous_function (false), m_nested_function (false),
+    m_class_constructor (none), m_class_method (none)
 {
-  if (cmd_list)
-    cmd_list->mark_as_function_body ();
+  if (m_cmd_list)
+    m_cmd_list->mark_as_function_body ();
 }
 
 octave_user_function::~octave_user_function (void)
 {
-  delete param_list;
-  delete ret_list;
-  delete lead_comm;
-  delete trail_comm;
-
-#if defined (HAVE_LLVM)
-  delete jit_info;
-#endif
+  delete m_param_list;
+  delete m_ret_list;
+  delete m_lead_comm;
+  delete m_trail_comm;
 }
 
 octave_user_function *
 octave_user_function::define_ret_list (octave::tree_parameter_list *t)
 {
-  ret_list = t;
+  m_ret_list = t;
 
   return this;
 }
@@ -262,22 +255,22 @@ octave_user_function::define_ret_list (octave::tree_parameter_list *t)
 void
 octave_user_function::maybe_relocate_end_internal (void)
 {
-  if (cmd_list && ! cmd_list->empty ())
+  if (m_cmd_list && ! m_cmd_list->empty ())
     {
-      octave::tree_statement *last_stmt = cmd_list->back ();
+      octave::tree_statement *last_stmt = m_cmd_list->back ();
 
       if (last_stmt && last_stmt->is_end_of_fcn_or_script ()
           && last_stmt->is_end_of_file ())
         {
           octave::tree_statement_list::reverse_iterator
-            next_to_last_elt = cmd_list->rbegin ();
+          next_to_last_elt = m_cmd_list->rbegin ();
 
           next_to_last_elt++;
 
           int new_eof_line;
           int new_eof_col;
 
-          if (next_to_last_elt == cmd_list->rend ())
+          if (next_to_last_elt == m_cmd_list->rend ())
             {
               new_eof_line = beginning_line ();
               new_eof_col = beginning_column ();
@@ -327,7 +320,7 @@ octave_user_function::profiler_name (void) const
 
   if (is_anonymous_function ())
     result << "anonymous@" << fcn_file_name ()
-           << ':' << location_line << ':' << location_column;
+           << ':' << m_location_line << ':' << m_location_column;
   else if (is_subfunction ())
     result << parent_fcn_name () << '>' << name ();
   else if (is_class_method ())
@@ -336,7 +329,7 @@ octave_user_function::profiler_name (void) const
     result << '@' << name ();
   else if (is_inline_function ())
     result << "inline@" << fcn_file_name ()
-           << ':' << location_line << ':' << location_column;
+           << ':' << m_location_line << ':' << m_location_column;
   else
     result << name ();
 
@@ -346,7 +339,7 @@ octave_user_function::profiler_name (void) const
 void
 octave_user_function::mark_as_system_fcn_file (void)
 {
-  if (! file_name.empty ())
+  if (! m_file_name.empty ())
     {
       // We really should stash the whole path to the file we found,
       // when we looked it up, to avoid possible race conditions...
@@ -357,14 +350,20 @@ octave_user_function::mark_as_system_fcn_file (void)
       // function file is parsed, it probably doesn't matter that
       // much.
 
-      std::string ff_name = octave::fcn_file_in_path (file_name);
+      std::string ff_name = octave::fcn_file_in_path (m_file_name);
+
+      static const std::string canonical_fcn_file_dir
+        = octave::sys::canonicalize_file_name
+          (octave::config::fcn_file_dir ());
+      static const std::string fcn_file_dir
+        = canonical_fcn_file_dir.empty () ? octave::config::fcn_file_dir ()
+          : canonical_fcn_file_dir;
 
-      std::string fcn_file_dir = octave::config::fcn_file_dir ();
       if (fcn_file_dir == ff_name.substr (0, fcn_file_dir.length ()))
-        system_fcn_file = true;
+        m_system_fcn_file = true;
     }
   else
-    system_fcn_file = false;
+    m_system_fcn_file = false;
 }
 
 void
@@ -376,13 +375,13 @@ octave_user_function::erase_subfunctions (void)
 bool
 octave_user_function::takes_varargs (void) const
 {
-  return (param_list && param_list->takes_varargs ());
+  return (m_param_list && m_param_list->takes_varargs ());
 }
 
 bool
 octave_user_function::takes_var_return (void) const
 {
-  return (ret_list && ret_list->takes_varargs ());
+  return (m_ret_list && m_ret_list->takes_varargs ());
 }
 
 void
@@ -411,35 +410,35 @@ octave_user_function::subfunctions (void) const
   return m_scope.subfunctions ();
 }
 
-// Find definition of final subfunction in list of subfuns:
+// Find definition of final subfunction in list of subfcns:
 //
 //  sub1>sub2>...>subN
 
 octave_value
-octave_user_function::find_subfunction (const std::string& subfuns_arg) const
+octave_user_function::find_subfunction (const std::string& subfcns_arg) const
 {
-  std::string subfuns = subfuns_arg;
+  std::string subfcns = subfcns_arg;
 
-  std::string first_fun = subfuns;
+  std::string first_fcn = subfcns;
 
-  size_t pos = subfuns.find ('>');
+  std::size_t pos = subfcns.find ('>');
 
   if (pos == std::string::npos)
-    subfuns = "";
+    subfcns = "";
   else
     {
-      first_fun = subfuns.substr (0, pos-1);
-      subfuns = subfuns.substr (pos+1);
+      first_fcn = subfcns.substr (0, pos-1);
+      subfcns = subfcns.substr (pos+1);
     }
 
-  octave_value ov_fcn = m_scope.find_subfunction (first_fun);
+  octave_value ov_fcn = m_scope.find_subfunction (first_fcn);
 
-  if (subfuns.empty ())
+  if (subfcns.empty ())
     return ov_fcn;
 
   octave_user_function *fcn = ov_fcn.user_function_value ();
 
-  return fcn->find_subfunction (subfuns);
+  return fcn->find_subfunction (subfcns);
 }
 
 bool
@@ -465,10 +464,10 @@ octave_user_function::all_va_args (const octave_value_list& args)
 {
   octave_value_list retval;
 
-  octave_idx_type n = args.length () - num_named_args;
+  octave_idx_type n = args.length () - m_num_named_args;
 
   if (n > 0)
-    retval = args.slice (num_named_args, n);
+    retval = args.slice (m_num_named_args, n);
 
   return retval;
 }
@@ -505,10 +504,10 @@ octave_user_function::accept (octave::tree_walker& tw)
 octave::tree_expression *
 octave_user_function::special_expr (void)
 {
-  assert (is_special_expr ());
-  assert (cmd_list->length () == 1);
+  panic_unless (is_special_expr ());
+  panic_if (m_cmd_list->length () != 1);
 
-  octave::tree_statement *stmt = cmd_list->front ();
+  octave::tree_statement *stmt = m_cmd_list->front ();
   return stmt->expression ();
 }
 
@@ -517,12 +516,12 @@ octave_user_function::subsasgn_optimization_ok (void)
 {
   bool retval = false;
   if (Voptimize_subsasgn_calls
-      && param_list && ret_list
-      && param_list->length () > 0 && ! param_list->varargs_only ()
-      && ret_list->length () == 1 && ! ret_list->takes_varargs ())
+      && m_param_list && m_ret_list
+      && m_param_list->length () > 0 && ! m_param_list->varargs_only ()
+      && m_ret_list->length () == 1 && ! m_ret_list->takes_varargs ())
     {
-      octave::tree_identifier *par1 = param_list->front ()->ident ();
-      octave::tree_identifier *ret1 = ret_list->front ()->ident ();
+      octave::tree_identifier *par1 = m_param_list->front ()->ident ();
+      octave::tree_identifier *ret1 = m_ret_list->front ()->ident ();
       retval = par1->name () == ret1->name ();
     }
 
@@ -534,7 +533,7 @@ octave_user_function::ctor_type_str (void) const
 {
   std::string retval;
 
-  switch (class_constructor)
+  switch (m_class_constructor)
     {
     case none:
       retval = "none";
@@ -561,7 +560,7 @@ octave_user_function::method_type_str (void) const
 {
   std::string retval;
 
-  switch (class_method)
+  switch (m_class_method)
     {
     case none:
       retval = "none";
@@ -587,20 +586,20 @@ octave_value
 octave_user_function::dump (void) const
 {
   std::map<std::string, octave_value> m
-    = {{ "user_code", octave_user_code::dump () },
-       { "line", location_line },
-       { "col", location_column },
-       { "end_line", end_location_line },
-       { "end_col", end_location_column },
-       { "parent_name", parent_name },
-       { "system_fcn_file", system_fcn_file },
-       { "num_named_args", num_named_args },
-       { "subfunction", subfunction },
-       { "inline_function", inline_function },
-       { "anonymous_function", anonymous_function },
-       { "nested_function", nested_function },
-       { "ctor_type", ctor_type_str () },
-       { "class_method", class_method }};
+  = {{ "user_code", octave_user_code::dump () },
+    { "line", m_location_line },
+    { "col", m_location_column },
+    { "end_line", m_end_location_line },
+    { "end_col", m_end_location_column },
+    { "system_fcn_file", m_system_fcn_file },
+    { "num_named_args", m_num_named_args },
+    { "subfunction", m_subfunction },
+    { "inline_function", m_inline_function },
+    { "anonymous_function", m_anonymous_function },
+    { "nested_function", m_nested_function },
+    { "ctor_type", ctor_type_str () },
+    { "class_method", m_class_method }
+  };
 
   return octave_value (m);
 }
@@ -624,8 +623,7 @@ octave_user_function::print_code_function_trailer (const std::string& prefix)
 void
 octave_user_function::restore_warning_states (void)
 {
-  octave::interpreter& interp
-    = octave::__get_interpreter__ ("octave_user_function::restore_warning_states");
+  octave::interpreter& interp = octave::__get_interpreter__ ();
 
   octave::tree_evaluator& tw = interp.get_evaluator ();
 
@@ -650,10 +648,12 @@ octave_user_function::restore_warning_states (void)
     }
 }
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 DEFMETHOD (nargin, interp, args, ,
            doc: /* -*- texinfo -*-
-@deftypefn  {} {} nargin ()
-@deftypefnx {} {} nargin (@var{fcn})
+@deftypefn  {} {@var{n} =} nargin ()
+@deftypefnx {} {@var{n} =} nargin (@var{fcn})
 Report the number of input arguments to a function.
 
 Called from within a function, return the number of arguments passed to the
@@ -692,25 +692,25 @@ Programming Note: @code{nargin} does not work on compiled functions
 
   if (nargin == 1)
     {
-      octave_value func = args(0);
+      octave_value fcn = args(0);
 
-      if (func.is_string ())
+      if (fcn.is_string ())
         {
-          octave::symbol_table& symtab = interp.get_symbol_table ();
+          symbol_table& symtab = interp.get_symbol_table ();
 
-          std::string name = func.string_value ();
-          func = symtab.find_function (name);
-          if (func.is_undefined ())
+          std::string name = fcn.string_value ();
+          fcn = symtab.find_function (name);
+          if (fcn.is_undefined ())
             error ("nargin: invalid function name: %s", name.c_str ());
         }
 
-      octave_function *fcn_val = func.function_value (true);
+      octave_function *fcn_val = fcn.function_value (true);
       if (! fcn_val)
         error ("nargin: FCN must be a string or function handle");
 
-      octave_user_function *fcn = fcn_val->user_function_value (true);
+      octave_user_function *ufcn = fcn_val->user_function_value (true);
 
-      if (! fcn)
+      if (! ufcn)
         {
           // Matlab gives up for histc, so maybe it's ok that we
           // give up sometimes too?
@@ -720,17 +720,17 @@ Programming Note: @code{nargin} does not work on compiled functions
                  type.c_str ());
         }
 
-      octave::tree_parameter_list *param_list = fcn->parameter_list ();
+      tree_parameter_list *m_param_list = ufcn->parameter_list ();
 
-      retval = (param_list ? param_list->length () : 0);
-      if (fcn->takes_varargs ())
+      retval = (m_param_list ? m_param_list->length () : 0);
+      if (ufcn->takes_varargs ())
         retval = -1 - retval;
     }
   else
     {
-      octave::tree_evaluator& tw = interp.get_evaluator ();
+      tree_evaluator& tw = interp.get_evaluator ();
 
-      retval = tw.get_auto_fcn_var (octave::stack_frame::NARGIN);
+      retval = tw.get_auto_fcn_var (stack_frame::NARGIN);
 
       if (retval.is_undefined ())
         retval = 0;
@@ -739,10 +739,10 @@ Programming Note: @code{nargin} does not work on compiled functions
   return retval;
 }
 
-DEFMETHOD (nargout, interp,args, ,
+DEFMETHOD (nargout, interp, args, ,
            doc: /* -*- texinfo -*-
-@deftypefn  {} {} nargout ()
-@deftypefnx {} {} nargout (@var{fcn})
+@deftypefn  {} {@var{n} =} nargout ()
+@deftypefnx {} {@var{n} =} nargout (@var{fcn})
 Report the number of output arguments from a function.
 
 Called from within a function, return the number of values the caller
@@ -803,36 +803,36 @@ returns -1 for all anonymous functions.
 
   if (nargin == 1)
     {
-      octave_value func = args(0);
+      octave_value fcn = args(0);
 
-      if (func.is_string ())
+      if (fcn.is_string ())
         {
-          octave::symbol_table& symtab = interp.get_symbol_table ();
+          symbol_table& symtab = interp.get_symbol_table ();
 
-          std::string name = func.string_value ();
-          func = symtab.find_function (name);
-          if (func.is_undefined ())
+          std::string name = fcn.string_value ();
+          fcn = symtab.find_function (name);
+          if (fcn.is_undefined ())
             error ("nargout: invalid function name: %s", name.c_str ());
         }
 
-      if (func.is_inline_function ())
+      if (fcn.is_inline_function ())
         return ovl (1);
 
-      if (func.is_function_handle ())
+      if (fcn.is_function_handle ())
         {
-          octave_fcn_handle *fh = func.fcn_handle_value ();
+          octave_fcn_handle *fh = fcn.fcn_handle_value ();
 
           if (fh->is_anonymous ())
             return ovl (-1);
         }
 
-      octave_function *fcn_val = func.function_value (true);
+      octave_function *fcn_val = fcn.function_value (true);
       if (! fcn_val)
         error ("nargout: FCN must be a string or function handle");
 
-      octave_user_function *fcn = fcn_val->user_function_value (true);
+      octave_user_function *ufcn = fcn_val->user_function_value (true);
 
-      if (! fcn)
+      if (! ufcn)
         {
           // Matlab gives up for histc, so maybe it's ok that we
           // give up sometimes too?
@@ -842,11 +842,11 @@ returns -1 for all anonymous functions.
                  type.c_str ());
         }
 
-      octave::tree_parameter_list *ret_list = fcn->return_list ();
+      tree_parameter_list *m_ret_list = ufcn->return_list ();
 
-      retval = (ret_list ? ret_list->length () : 0);
+      retval = (m_ret_list ? m_ret_list->length () : 0);
 
-      if (fcn->takes_var_return ())
+      if (ufcn->takes_var_return ())
         retval = -1 - retval;
     }
   else
@@ -854,9 +854,9 @@ returns -1 for all anonymous functions.
       if (interp.at_top_level ())
         error ("nargout: invalid call at top level");
 
-      octave::tree_evaluator& tw = interp.get_evaluator ();
+      tree_evaluator& tw = interp.get_evaluator ();
 
-      retval = tw.get_auto_fcn_var (octave::stack_frame::NARGOUT);
+      retval = tw.get_auto_fcn_var (stack_frame::NARGOUT);
 
       if (retval.is_undefined ())
         retval = 0;
@@ -869,7 +869,7 @@ DEFUN (optimize_subsasgn_calls, args, nargout,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{val} =} optimize_subsasgn_calls ()
 @deftypefnx {} {@var{old_val} =} optimize_subsasgn_calls (@var{new_val})
-@deftypefnx {} {} optimize_subsasgn_calls (@var{new_val}, "local")
+@deftypefnx {} {@var{old_val} =} optimize_subsasgn_calls (@var{new_val}, "local")
 Query or set the internal flag for @code{subsasgn} method call
 optimizations.
 
@@ -882,7 +882,8 @@ The original variable value is restored when exiting the function.
 @seealso{subsasgn}
 @end deftypefn */)
 {
-  return SET_INTERNAL_VARIABLE (optimize_subsasgn_calls);
+  return set_internal_variable (Voptimize_subsasgn_calls, args, nargout,
+                                "optimize_subsasgn_calls");
 }
 
 static bool val_in_table (const Matrix& table, double val)
@@ -896,7 +897,7 @@ static bool val_in_table (const Matrix& table, double val)
 
 static bool isargout1 (int nargout, const Matrix& ignored, double k)
 {
-  if (k != octave::math::fix (k) || k <= 0)
+  if (k != math::fix (k) || k <= 0)
     error ("isargout: K must be a positive integer");
 
   return (k == 1 || k <= nargout) && ! val_in_table (ignored, k);
@@ -904,7 +905,7 @@ static bool isargout1 (int nargout, const Matrix& ignored, double k)
 
 DEFMETHOD (isargout, interp, args, ,
            doc: /* -*- texinfo -*-
-@deftypefn {} {} isargout (@var{k})
+@deftypefn {} {@var{tf} =} isargout (@var{k})
 Within a function, return a logical value indicating whether the argument
 @var{k} will be assigned to a variable on output.
 
@@ -926,17 +927,17 @@ element-by-element and a logical array is returned.  At the top level,
   if (interp.at_top_level ())
     error ("isargout: invalid call at top level");
 
-  octave::tree_evaluator& tw = interp.get_evaluator ();
+  tree_evaluator& tw = interp.get_evaluator ();
 
   octave_value tmp;
 
   int nargout1 = 0;
-  tmp = tw.get_auto_fcn_var (octave::stack_frame::NARGOUT);
+  tmp = tw.get_auto_fcn_var (stack_frame::NARGOUT);
   if (tmp.is_defined ())
     nargout1 = tmp.int_value ();
 
   Matrix ignored;
-  tmp = tw.get_auto_fcn_var (octave::stack_frame::IGNORED);
+  tmp = tw.get_auto_fcn_var (stack_frame::IGNORED);
   if (tmp.is_defined ())
     ignored = tmp.matrix_value ();
 
@@ -1031,3 +1032,5 @@ element-by-element and a logical array is returned.  At the top level,
 %! [~, b] = try_isargout2 ({try_isargout, try_isargout}, rand);
 %! assert (b, {0, 1, {-1, -1}});
 */
+
+OCTAVE_END_NAMESPACE(octave)
