@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2019-2021 The Octave Project Developers
+// Copyright (C) 2019-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -28,49 +28,48 @@
 
 #include "octave-config.h"
 
-namespace octave
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+class filepos
 {
-  class filepos
+public:
+
+  filepos (void) : m_line (0), m_column (0) { }
+
+  filepos (int l, int c) : m_line (l), m_column (c) { }
+
+  filepos (const filepos&) = default;
+
+  filepos& operator = (const filepos&) = default;
+
+  ~filepos (void) = default;
+
+  operator bool () { return m_line > 0 && m_column > 0; }
+
+  void line (int l) { m_line = l; }
+  void column (int c) { m_column = c; }
+
+  int line (void) const { return m_line; }
+  int column (void) const { return m_column; }
+
+  void increment_line (int val = 1) { m_line += val; }
+  void increment_column (int val = 1) { m_column += val; }
+
+  void decrement_line (int val = 1) { m_line -= val; }
+  void decrement_column (int val = 1) { m_column -= val; }
+
+  void next_line (void)
   {
-  public:
+    m_line++;
+    m_column = 1;
+  }
 
-    filepos (int l = 1, int c = 1) : m_line (l), m_column (c) { }
+private:
 
-    filepos (const filepos&) = default;
+  int m_line;
+  int m_column;
+};
 
-    filepos& operator = (const filepos&) = default;
-
-    ~filepos (void) = default;
-
-    void set (int l, int c)
-    {
-      m_line = l;
-      m_column = c;
-    }
-
-    void line (int l) { m_line = l; }
-    void column (int c) { m_column = c; }
-
-    int line (void) const { return m_line; }
-    int column (void) const { return m_column; }
-
-    void increment_line (int val = 1) { m_line += val; }
-    void increment_column (int val = 1) { m_column += val; }
-
-    void decrement_line (int val = 1) { m_line -= val; }
-    void decrement_column (int val = 1) { m_column -= val; }
-
-    void next_line (void)
-    {
-      m_line++;
-      m_column = 1;
-    }
-
-  private:
-
-    int m_line;
-    int m_column;
-  };
-}
+OCTAVE_END_NAMESPACE(octave)
 
 #endif
