@@ -1,24 +1,31 @@
-## Copyright (C) 2004-2015 John Eaton and David Bateman
+########################################################################
+##
+## Copyright (C) 2004-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{y} =} shiftdim (@var{x}, @var{n})
-## @deftypefnx {Function File} {[@var{y}, @var{ns}] =} shiftdim (@var{x})
+## @deftypefn  {} {@var{y} =} shiftdim (@var{x}, @var{n})
+## @deftypefnx {} {[@var{y}, @var{ns}] =} shiftdim (@var{x})
 ## Shift the dimensions of @var{x} by @var{n}, where @var{n} must be
 ## an integer scalar.
 ##
@@ -37,12 +44,14 @@
 ## @group
 ## x = ones (1, 2, 3);
 ## size (shiftdim (x, -1))
-##    @result{} [1, 1, 2, 3]
+##   @result{}   1   1   2   3
 ## size (shiftdim (x, 1))
-##    @result{} [2, 3]
+##   @result{}   2   3
 ## [b, ns] = shiftdim (x)
-##    @result{} b = [1, 1, 1; 1, 1, 1]
-##    @result{} ns = 1
+##   @result{} b =
+##         1   1   1
+##         1   1   1
+##   @result{} ns = 1
 ## @end group
 ## @end example
 ## @seealso{reshape, permute, ipermute, circshift, squeeze}
@@ -50,7 +59,7 @@
 
 function [y, ns]  = shiftdim (x, n)
 
-  if (nargin < 1 || nargin > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -95,8 +104,6 @@ endfunction
 %!assert (size (shiftdim (rand (0, 1, 2))), [0 1 2])
 
 ## Test input validation
-%!error (shiftdim ())
-%!error (shiftdim (1,2,3))
-%!error (shiftdim (1, ones (2)))
-%!error (shiftdim (1, 1.5))
-
+%!error <Invalid call> shiftdim ()
+%!error shiftdim (1, ones (2))
+%!error shiftdim (1, 1.5)
