@@ -1,4 +1,9 @@
-## Copyright (C) 1997-2018 Vincent Cautaerts
+########################################################################
+##
+## Copyright (C) 1997-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,10 +20,12 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} fftshift (@var{x})
-## @deftypefnx {} {} fftshift (@var{x}, @var{dim})
+## @deftypefn  {} {@var{y} =} fftshift (@var{x})
+## @deftypefnx {} {@var{y} =} fftshift (@var{x}, @var{dim})
 ## Perform a shift of the vector @var{x}, for use with the @code{fft} and
 ## @code{ifft} functions, in order to move the frequency 0 to the center of
 ## the vector or matrix.
@@ -42,13 +49,9 @@
 ## @seealso{ifftshift}
 ## @end deftypefn
 
-## Author: Vincent Cautaerts <vincent@comf5.comm.eng.osaka-u.ac.jp>
-## Created: July 1997
-## Adapted-By: jwe
+function y = fftshift (x, dim)
 
-function retval = fftshift (x, dim)
-
-  if (nargin != 1 && nargin != 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -66,12 +69,12 @@ function retval = fftshift (x, dim)
     idx = cell ();
     idx = repmat ({':'}, nd, 1);
     idx{dim} = [sz2+1:sz(dim), 1:sz2];
-    retval = x(idx{:});
+    y = x(idx{:});
   else
     if (isvector (x))
       xl = length (x);
       xx = ceil (xl/2);
-      retval = x([xx+1:xl, 1:xx]);
+      y = x([xx+1:xl, 1:xx]);
     else
       nd = ndims (x);
       sz = size (x);
@@ -80,7 +83,7 @@ function retval = fftshift (x, dim)
       for i = 1:nd
         idx{i} = [sz2(i)+1:sz(i), 1:sz2(i)];
       endfor
-      retval = x(idx{:});
+      y = x(idx{:});
     endif
   endif
 
@@ -148,7 +151,6 @@ endfunction
 %! assert (fftshift (y), x);
 
 ## Test input validation
-%!error fftshift ()
-%!error fftshift (1, 2, 3)
+%!error <Invalid call> fftshift ()
 %!error fftshift (0:3, -1)
 %!error fftshift (0:3, 0:3)
