@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2008-2021 The Octave Project Developers
+## Copyright (C) 2008-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -36,8 +36,8 @@
 ##
 ## @item @var{A} is the matrix of the linear system and it must be square.
 ## @var{A} can be passed as a matrix, function handle, or inline
-## function @code{Afun} such that @code{Afun(x) = A * x}.  Additional
-## parameters to @code{Afun} are passed after @var{x0}.
+## function @code{Afcn} such that @code{Afcn(x) = A * x}.  Additional
+## parameters to @code{Afcn} are passed after @var{x0}.
 ##
 ## @item @var{b} is the right hand side vector.  It must be a column vector
 ## with the same number of rows as @var{A}.
@@ -118,10 +118,10 @@
 ## restart = 5;
 ## [M1, M2] = ilu (A); # in this tridiag case, it corresponds to lu (A)
 ## M = M1 * M2;
-## Afun = @@(x) A * x;
-## Mfun = @@(x) M \ x;
-## M1fun = @@(x) M1 \ x;
-## M2fun = @@(x) M2 \ x;
+## Afcn = @@(x) A * x;
+## Mfcn = @@(x) M \ x;
+## M1fcn = @@(x) M1 \ x;
+## M2fcn = @@(x) M2 \ x;
 ## @end group
 ## @end example
 ##
@@ -135,7 +135,7 @@
 ## @code{@var{A} * @var{x}}
 ##
 ## @example
-## x = bicgstab (Afun, b, [], n)
+## x = bicgstab (Afcn, b, [], n)
 ## @end example
 ##
 ## @sc{Example 3:} @code{bicgstab} with a preconditioner matrix @var{M}
@@ -147,7 +147,7 @@
 ## @sc{Example 4:} @code{bicgstab} with a function as preconditioner
 ##
 ## @example
-## x = bicgstab (Afun, b, 1e-6, n, Mfun)
+## x = bicgstab (Afcn, b, 1e-6, n, Mfcn)
 ## @end example
 ##
 ## @sc{Example 5:} @code{bicgstab} with preconditioner matrices @var{M1}
@@ -160,7 +160,7 @@
 ## @sc{Example 6:} @code{bicgstab} with functions as preconditioners
 ##
 ## @example
-## x = bicgstab (Afun, b, 1e-6, n, M1fun, M2fun)
+## x = bicgstab (Afcn, b, 1e-6, n, M1fcn, M2fcn)
 ## @end example
 ##
 ## @sc{Example 7:} @code{bicgstab} with as input a function requiring
@@ -174,8 +174,8 @@
 ##      y = A * y;
 ##    endfor
 ##  endfunction
-## Apfun = @@(x, string, p) Ap (A, x, string, p);
-## x = bicgstab (Apfun, b, [], [], [], [], [], 2);
+## Apfcn = @@(x, string, p) Ap (A, x, string, p);
+## x = bicgstab (Apfcn, b, [], [], [], [], [], 2);
 ## @end group
 ## @end example
 ##
@@ -211,24 +211,24 @@ function [x_min, flag, relres, iter_min, resvec] = ...
                    x0 = [], varargin)
 
   ## Check consistency and  type of A, M1, M2
-  [Afun, M1fun, M2fun] =  __alltohandles__ (A, b, M1, M2, "bicgstab");
+  [Afcn, M1fcn, M2fcn] =  __alltohandles__ (A, b, M1, M2, "bicgstab");
 
-  # Check if input tol are empty (set them to default if necessary)
+  ## Check if input tol are empty (set them to default if necessary)
   [tol, maxit, x0] = __default__input__ ({1e-06, min(rows(b), 20), ...
-                    zeros(rows(b), 1)}, tol, maxit, x0);
+                    zeros(rows (b), 1)}, tol, maxit, x0);
 
   norm_b = norm (b, 2);
   if (norm_b == 0)
     if (nargout < 2)
-      printf("The right hand side vector is all zero so bicgstab \n")
+      printf ("The right hand side vector is all zero so bicgstab \n")
       printf ("returned an all zero solution without iterating.\n")
     endif
     x_min = zeros (numel (b), 1);
-    iter_ min = 0;
+    iter_min = 0;
     flag = 0;
     resvec = 0;
     relres = 0;
-    return
+    return;
   endif
 
   ## Double maxit to mind also the "half iterations"
@@ -240,7 +240,7 @@ function [x_min, flag, relres, iter_min, resvec] = ...
   ## default setting of flag is 1 (i.e. max number of iterations reached)
   flag = 1;
 
-  res = b - feval (Afun, x, varargin{:});
+  res = b - feval (Afcn, x, varargin{:});
   rr = p = res; # rr is r_star
   rho_1 = rr' * res;
   resvec (1) = norm (res,2);
@@ -248,15 +248,15 @@ function [x_min, flag, relres, iter_min, resvec] = ...
 
   ## To check if the preconditioners are singular or they have some NaN
   try
-    warning("error", "Octave:singular-matrix", "local");
-    p_hat = feval (M1fun, p, varargin{:});
-    p_hat = feval (M2fun, p_hat, varargin{:});
+    warning ("error", "Octave:singular-matrix", "local");
+    p_hat = feval (M1fcn, p, varargin{:});
+    p_hat = feval (M2fcn, p_hat, varargin{:});
   catch
     flag = 2;
   end_try_catch
 
   while (flag !=2) && (iter < d_maxit) && (resvec (iter + 1) >= real_tol)
-    v = feval (Afun, p_hat, varargin{:});
+    v = feval (Afcn, p_hat, varargin{:});
     prod_tmp = (rr' * v);
     if (prod_tmp == 0)
       flag = 4;
@@ -270,14 +270,14 @@ function [x_min, flag, relres, iter_min, resvec] = ...
     if (resvec (iter + 1) <= real_tol) # reached the tol
       x_min = x;
       iter_min = iter;
-      break
+      break;
     elseif (resvec (iter + 1) <= resvec (iter_min + 1)) # Found min residual
       x_min = x;
       iter_min = iter;
     endif
-    s_hat = feval (M1fun, s, varargin{:});
-    s_hat = feval (M2fun, s_hat, varargin{:});
-    t = feval (Afun, s_hat, varargin{:});
+    s_hat = feval (M1fcn, s, varargin{:});
+    s_hat = feval (M2fcn, s_hat, varargin{:});
+    t = feval (Afcn, s_hat, varargin{:});
     omega = (t' * s) / (t' * t);
     if (omega == 0) # x and residual don't change and the next it will be NaN
       flag = 4;
@@ -293,7 +293,7 @@ function [x_min, flag, relres, iter_min, resvec] = ...
     endif
     if (norm (x - x_pr) <= norm (x) * eps)
       flag = 3;
-      break
+      break;
     endif
     x_pr = x;
     rho_2 = rho_1;
@@ -304,12 +304,12 @@ function [x_min, flag, relres, iter_min, resvec] = ...
     endif
     beta = (rho_1 / rho_2) * (alpha / omega);
     p = res + beta * (p - omega*  v);
-    p_hat = feval (M1fun, p, varargin{:});
-    p_hat = feval (M2fun, p_hat, varargin{:});
+    p_hat = feval (M1fcn, p, varargin{:});
+    p_hat = feval (M2fcn, p_hat, varargin{:});
   endwhile
   resvec = resvec (1:iter+1,1);
 
-  relres = resvec (iter_min + 1) / norm_b; ## I set the relative residual
+  relres = resvec (iter_min + 1) / norm_b;  # I set the relative residual
   iter /=  2;
   iter_min /= 2;
 
@@ -362,15 +362,15 @@ endfunction
 %! [M1, M2] = ilu (A + 0.1 * eye (n));
 %! M = M1 * M2;
 %! x = bicgstab (A, b, [], n);
-%! Afun = @(x) A * x;
-%! x = bicgstab (Afun, b, [], n);
+%! Afcn = @(x) A * x;
+%! x = bicgstab (Afcn, b, [], n);
 %! x = bicgstab (A, b, 1e-6, n, M);
 %! x = bicgstab (A, b, 1e-6, n, M1, M2);
-%! Mfun = @(z) M \ z;
-%! x = bicgstab (Afun, b, 1e-6, n, Mfun);
-%! M1fun = @(z) M1 \ z;
-%! M2fun = @(z) M2 \ z;
-%! x = bicgstab (Afun, b, 1e-6, n, M1fun, M2fun);
+%! Mfcn = @(z) M \ z;
+%! x = bicgstab (Afcn, b, 1e-6, n, Mfcn);
+%! M1fcn = @(z) M1 \ z;
+%! M2fcn = @(z) M2 \ z;
+%! x = bicgstab (Afcn, b, 1e-6, n, M1fcn, M2fcn);
 %! function y = Ap (A, x, z)
 %!   ## compute A^z * x or (A^z)' * x
 %!   y = x;
@@ -378,8 +378,8 @@ endfunction
 %!     y = A * y;
 %!   endfor
 %! endfunction
-%! Afun = @(x, p) Ap (A, x, p);
-%! x = bicgstab (Afun, b, [], 2 * n, [], [], [], 2); # solution of A^2 * x = b
+%! Afcn = @(x, p) Ap (A, x, p);
+%! x = bicgstab (Afcn, b, [], 2 * n, [], [], [], 2); # solution of A^2 * x = b
 
 %!demo
 %! n = 10;
@@ -406,28 +406,28 @@ endfunction
 %! M1 = diag (sqrt (diag (A)));
 %! M2 = M1;
 %! maxit = 20;
-%! Afun = @(z) A*z;
-%! M1_fun = @(z) M1 \ z;
-%! M2_fun = @(z) M2 \ z;
+%! Afcn = @(z) A*z;
+%! M1_fcn = @(z) M1 \ z;
+%! M2_fcn = @(z) M2 \ z;
 %! [x, flag] = bicgstab (A,b );
 %! assert (flag, 0);
 %! [x, flag] = bicgstab (A, b, [], maxit, M1, M2);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (A, b, [], maxit, M1_fun, M2_fun);
+%! [x, flag] = bicgstab (A, b, [], maxit, M1_fcn, M2_fcn);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (A, b, [], maxit, M1_fun, M2);
+%! [x, flag] = bicgstab (A, b, [], maxit, M1_fcn, M2);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (A, b, [], maxit, M1, M2_fun);
+%! [x, flag] = bicgstab (A, b, [], maxit, M1, M2_fcn);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (Afun, b);
+%! [x, flag] = bicgstab (Afcn, b);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (Afun, b, [], maxit, M1, M2);
+%! [x, flag] = bicgstab (Afcn, b, [], maxit, M1, M2);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (Afun, b, [], maxit, M1_fun, M2);
+%! [x, flag] = bicgstab (Afcn, b, [], maxit, M1_fcn, M2);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (Afun, b, [], maxit, M1, M2_fun);
+%! [x, flag] = bicgstab (Afcn, b, [], maxit, M1, M2_fcn);
 %! assert (flag, 0);
-%! [x, flag] = bicgstab (Afun, b, [], maxit, M1_fun, M2_fun);
+%! [x, flag] = bicgstab (Afcn, b, [], maxit, M1_fcn, M2_fcn);
 %! assert (flag, 0);
 
 %!shared n, A, b, tol, maxit, M1, M2
@@ -443,12 +443,12 @@ endfunction
 %! [x, flag, relres, iter, resvec] = bicgstab (A, b, tol, maxit, M1, M2);
 %! assert (norm (b - A*x) / norm (b), 0, tol);
 
-%!function y = afun (x, a)
+%!function y = afcn (x, a)
 %!  y = a * x;
 %!endfunction
 %!
 %!test
-%! [x, flag, relres, iter, resvec] = bicgstab (@(x) afun (x, A), b,
+%! [x, flag, relres, iter, resvec] = bicgstab (@(x) afcn (x, A), b,
 %!                                             tol, maxit, M1, M2);
 %! assert (norm (b - A*x) / norm (b), 0, tol);
 
@@ -501,13 +501,13 @@ endfunction
 %! assert (class (x), "single");
 
 %!test
-%!function y = Afun (x)
+%!function y = Afcn (x)
 %!  A = sparse (toeplitz ([2, 1, 0, 0], [2, -1, 0, 0]));
 %!  y = A * x;
 %!endfunction
 %!
 %! b = [1; 2; 2; 3];
-%! [x, flag] = bicgstab ("Afun", b);
+%! [x, flag] = bicgstab ("Afcn", b);
 %! assert (norm (b - A*x) / norm (b), 0, 1e-6);
 
 %!test
